'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var path = _interopDefault(require('path'));
var fs = _interopDefault(require('fs'));
var HtmlWebpackPlugin = _interopDefault(require('html-webpack-plugin'));

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

var WRAPPER_ID = 'webpack-progress-indicator-wrapper';
var MSG_ID = 'webpack-progress-indicator-message';
var PROGRESS_ID = 'webpack-progress-indicator-percentage';
var defaultIndicator = /*#__PURE__*/path.join(__dirname, '../variants/indicator-template.html');
var nyanIndicator = /*#__PURE__*/path.join(__dirname, '../variants/nyan-indicator.html');
var defaultOptions = {
  placeholder: '<!-- reload-indicator-placeholder -->',
  template: defaultIndicator
};
var HtmlProgressIndicatorPlugin = /*#__PURE__*/function () {
  function HtmlProgressIndicatorPlugin(options) {
    if (options === void 0) {
      options = {};
    }
    this.name = 'ReloadIndicatorPlugin';
    this.options = _extends({}, defaultOptions, options);
    this.indicatorTemplate = this.options.template === 'nyan' ? fs.readFileSync(nyanIndicator, 'utf8') : this.options.template === 'default' ? fs.readFileSync(defaultIndicator, 'utf8') : fs.existsSync(this.options.template) ? fs.readFileSync(this.options.template, 'utf8') : this.options.template || fs.readFileSync(defaultIndicator, 'utf8');
  }
  var _proto = HtmlProgressIndicatorPlugin.prototype;
  _proto.apply = function apply(compiler) {
    var _this = this;
    compiler.hooks.compilation.tap(this.name, function (compilation) {
      HtmlWebpackPlugin.getHooks(compilation).beforeEmit.tapAsync(_this.name, function (data, cb) {
        var _compilation$options$, _compilation$options$2, _compilation$options$3, _compilation$options$4, _compilation$options$5, _compilation$options$6;
        // Get configured socket URL
        var host = ((_compilation$options$ = compilation.options.devServer) == null ? void 0 : (_compilation$options$2 = _compilation$options$.client) == null ? void 0 : (_compilation$options$3 = _compilation$options$2.webSocketURL) == null ? void 0 : _compilation$options$3.hostname) || 'localhost';
        var port = ((_compilation$options$4 = compilation.options.devServer) == null ? void 0 : (_compilation$options$5 = _compilation$options$4.client) == null ? void 0 : (_compilation$options$6 = _compilation$options$5.webSocketURL) == null ? void 0 : _compilation$options$6.port) || 8080;
        data.html = data.html.replace(_this.options.placeholder, /* html */"\n              " + _this.indicatorTemplate.replaceAll('{{PROGRESS_ID}}', PROGRESS_ID).replaceAll('{{WRAPPER_ID}}', WRAPPER_ID).replaceAll('{{MSG_ID}}', MSG_ID) + " \n\n              <script>\n                  // Open up a websocket connection to webpack-dev-server\n                  let socket = new WebSocket('ws://" + host + ":" + port + "/ws');\n\n                  socket.addEventListener('message', (message) => {\n                      const event = JSON.parse(message.data);\n                      const wrapper = document.getElementById('" + WRAPPER_ID + "');\n                      const msg = document.getElementById('" + MSG_ID + "');\n                      const progress = document.getElementById('" + PROGRESS_ID + "');\n\n                      // We only care about the progress event\n                      if (event.type === 'progress-update') {\n                        msg.innerText = event.data.msg;\n                        progress.innerText = event.data.percent + '%';\n                        \n                        if (event.data.percent === 100) {\n                          wrapper.style.display = 'none';\n                        } else {\n                          wrapper.style.display = 'flex';\n                        }\n                      }\n                  });\n              </script>\n            ");
        cb(null, data);
      });
    });
  };
  return HtmlProgressIndicatorPlugin;
}();

exports.HtmlProgressIndicatorPlugin = HtmlProgressIndicatorPlugin;
exports.MSG_ID = MSG_ID;
exports.PROGRESS_ID = PROGRESS_ID;
exports.WRAPPER_ID = WRAPPER_ID;
//# sourceMappingURL=html-progress-indicator-plugin.cjs.development.js.map
